``ExposoGraph.seeder``
======================

Database seeding helpers for KEGG, CTD, and IARC-backed enrichment.

KEGG and CTD seeders accept a ``mode`` argument so seeded graphs can be
prepared in ``exploratory`` or ``strict`` mode before merge.

.. automodule:: ExposoGraph.seeder
   :members:
   :undoc-members:
